/*****************************************************************************************
******************************************************************************************
Nom du fichier:SSI2.h
------------------------------------------------------------------------------------------
Auteur: Philippe MARIANO
------------------------------------------------------------------------------------------
Rle: fichier d'en-tte de la bibliothque ssi2.lib
------------------------------------------------------------------------------------------
Cr le : 10/03/2003
Dernire rvision le : 26/10/2010
------------------------------------------------------------------------------------------
Cross compilateur utilis: CodeVisionAVR V2.04.08
------------------------------------------------------------------------------------------
Composants cibles : ATMEL 8 bits
------------------------------------------------------------------------------------------
CIBLE HARDWARE: Carte pour les TP ATMEL SSI V1 ou V2
------------------------------------------------------------------------------------------
Remarques:
Ce fichier est destin  un projet CVAVR utilisant la carte SSI
Il doit tre plac dans le sous rpertoire \CVAVR\INC\
Placer le fichier ssi.lib dans le rpertoire \CVAVR\LIB\
ou placcer les deux fichiers dans le rpertoire du projet 
*****************************************************************************************
*****************************************************************************************/

#ifndef _SSI2_INCLUDED_ 		// Evite que le fichier ne soit inclus plusieurs fois
#define _SSI2_INCLUDED_

// -----------------------------------------------------------------------------------------
//Interrupt vectors definitions
// -----------------------------------------------------------------------------------------
#ifndef EXT_INT0
#define EXT_INT0	2
#endif


// -----------------------------------------------------------------------------------------
// Dfinition du code des BPs de la carte ATMEL SSI V1 ou V2
// -----------------------------------------------------------------------------------------
#ifndef INC
#define INC			0b00011111   	// 0x1f
#endif
#ifndef DEC
#define DEC			0b00101111      // 0x2f
#endif
#ifndef OK
#define OK			0b00110111		// 0x37
#endif
#ifndef ECHAP
#define ECHAP		0b00111011      // 0x3b
#endif
#ifndef SET
#define SET			0b00111101      // 0x3d
#endif
#ifndef ENTR
#define ENTR		0b00111110      // 0x3e
#endif


// ******************************************************************************************
// ******************************************************************************************
// Codes de commande de l'afficheur LCD 2x16  processeur Hitachi type HD44780
// ******************************************************************************************
// ******************************************************************************************
// Utilisation: A crire dans le registre de contrle de l'afficheur
// avec une instruction _lcd_write_data(unsigned char data) prcde d'une instruction
// _lcd_ready(void) de la librairie lcd.h
// ******************************************************************************************
// -----------------------------------------------------------------------------------------
// Initialisation du dplacement du curseur
// -----------------------------------------------------------------------------------------
#ifndef EntryMode0
#define EntryMode0      0b00000100 	// Par dfaut dplacement du curseur vers la gauche
#endif
#ifndef EntryMode1
#define EntryMode1      0b00000101 	// Par dfaut dplacement de l'affichage vers la gauche
#endif
#ifndef EntryMode2
#define EntryMode2      0b00000110 	// Par dfaut dplacement du curseur vers la droite
#endif
#ifndef EntryMode3
#define EntryMode3      0b00000111 	// Par dfaut dplacement de l'affichage vers la droite
#endif
#ifndef clear
#define clear           0b00000001 	// Efface l'cran et la DDRAM
#endif
#ifndef home
#define home            0b00000010 	// Ramne le curseur au dbut de la premire ligne
#endif
// -----------------------------------------------------------------------------------------
// Affichage             Code       	On/Off         curseur      	clignotement
// -----------------------------------------------------------------------------------------
#ifndef displayOff0
#define displayOff0     0b00001000  	//  Off      invisible     		non
#endif
#ifndef displayOff1
#define displayOff1     0b00001001  	//  Off      invisible     		oui
#endif
#ifndef displayOff2
#define displayOff2     0b00001010  	//  Off      visible       		non
#endif
#ifndef displayOff3
#define displayOff3     0b00001011  	//  Off      visible       		oui
#endif
#ifndef displayOn0
#define displayOn0      0b00001100  	//  On       invisible     		non
#endif
#ifndef displayOn1
#define displayOn1      0b00001101  	//  On       invisible     		oui
#endif
#ifndef displayOn2
#define displayOn2      0b00001110  	//  On       visible       		non
#endif
#ifndef displayOn3
#define displayOn3      0b00001111  	//  On       visible       		oui
#endif
// -----------------------------------------------------------------------------------------
// Dplacement du curseur ou de l'affichage
// -----------------------------------------------------------------------------------------
#ifndef curseurG
#define curseurG        0b00010000 	// Dplacement du curseur vers la gauche
#endif
#ifndef curseurD
#define curseurD        0b00010100 	// Dplacement du curseur vers la droite
#endif
#ifndef fenetreG
#define fenetreG        0b00011000 	// Dplacement de l'affichage vers la gauche
#endif
#ifndef fenetreD
#define fenetreD        0b00011100 	// Dplacement de l'affichage vers la droite
#endif
// -----------------------------------------------------------------------------------------
// -----------------------------------------------------------------------------------------
// Construction d'un caractre personalis. Codes  crire dans la CGRAM
// aux adresses $40, $48, $50, $58, $60, $68, $70, $78 avec une instruction
// lcd_write_byte(unsigned char adresse, unsigned char data)
// -----------------------------------------------------------------------------------------
// Exemple de dclaration d'une matrice 5x7, le 8e caractre correspond au curseur
// const unsigned char flecheHaut[8] = {0x04, 0x0E, 0x15, 0x04, 0x04, 0x04, 0x04, 0x00};
// 00100
// 01110
// 10101
// 00100
// 00100
// 00100
// 00100
// 00000
// ******************************************************************************************


// ******************************************************************************************
// ******************************************************************************************
// Prototype des fonctions gnrales de la carte SSI
// ******************************************************************************************
// ******************************************************************************************
// 1 - unsigned char Lire_BP(void);
// 2 - void Affiche_LCD(char *ligne1,char *ligne2);
// 3 - unsigned char eeprom_read(unsigned char addcase, unsigned int adressmap);
// 4 - void eeprom_write(unsigned char addcase, unsigned char adressmap,
// unsigned char data);
// 5 - void eeprom_page_read(unsigned char addcase, unsigned int adressmap,
// unsigned char *display_buffer);
// 6 - int regle_HTR(unsigned char adresse,unsigned char Heure_ou_Date, char H_J,
// char mn_mois, int sec_annee);
// ******************************************************************************************

#pragma used+
// --------------------------------------------------------------------------------------------------------
unsigned char Lire_BP(void);
/* --------------------------------------------------------------------------------------------------------
Rle : Lit l'tat des BP de la carte ATMEL SSI(PortA) et renvoie un code sur 8 bits.

Commentaires : Dans un premier temps, la fonction renvoie le code de la touche actionne
(INC = 0x1F, DEC = Ox2f, OK = 0x37, ECHAP = 0x3B, SET = 0x3D, ENTR=0x3E)
puis elle renvoie 0x00 si la touche est maintenue ou 0xFF si la touche est relche.

Entres : aucunes

Sortie : code de la touche ou 0x00 ou 0xFF
---------------------------------------------------------------------------------------------------------*/

// --------------------------------------------------------------------------------------------------------
void Affiche_LCD(char *ligne0,char *ligne1);
/* --------------------------------------------------------------------------------------------------------
Rle : Gre l'affichage d'un LCD quip d'un contrleur Hitachi (command en mode 4 bits)

Commentaires : Envoie le contenu de deux tableaux de 16 caractres sur les lignes 0 et
1 d'un afficheur LCD 2*16 caractres.
Chaque tableau doit pouvoir contenir 17 valeurs (les 16 caractres  afficher + \0)

Librairie utilis : lcd.h

Entres : ligne0, ligne1 = tableaux de 17 caractres

Sorties : Aucune
---------------------------------------------------------------------------------------------------------*/

// --------------------------------------------------------------------------------------------------------
unsigned char eeprom_read(unsigned char addcase, unsigned int adressmap);
/* --------------------------------------------------------------------------------------------------------
Rle : Lit un octet dans une mmoire srie gre par le protocole I2C

Commentaires : A utiliser avec les mmoires > 256 octets

Librairie utilise : I2C.h

Entres :
      addcase 	: Octet de commande du botier mmoire. Construit par 1 0 1 0 A2 A1 A0 R/W
                remarque (R/W doit tre mis  zro)
      adressmap : adresse  atteindre dans le botier

Sortie : contenu de l'adresse adressmap du botier situ en addcase
---------------------------------------------------------------------------------------------------------*/

// --------------------------------------------------------------------------------------------------------
void eeprom_write(unsigned char addcase, unsigned char adressmap, unsigned char data);
/* --------------------------------------------------------------------------------------------------------
Rle : Ecrit un octet dans une mmoire srie gre par le protocole I2C

Commentaires : A utiliser avec les mmoires > 256 octets

Librairie utilise : I2C.h et delay.h

Entres :
      addcase 	: adresse du botier mmoire construit par 1 0 1 0 A2 A1 A0 R/W
                remarque (R/W doit tre mis  zro)
      adressmap : adresse  atteindre dans le botier
      data 	: octet  crire  la position adressmap du botier situ en addcase

Sorties : aucune
---------------------------------------------------------------------------------------------------------*/

// --------------------------------------------------------------------------------------------------------
void eeprom_page_read(unsigned char addcase, unsigned int adressmap, unsigned char *display_buffer);
/* --------------------------------------------------------------------------------------------------------
Rle : Lit 32 octets dans une mmoire srie gre par le protocole I2C

Commentaires : A utiliser avec les mmoires > 256 octets

Librairie utilise : I2C.h

Entres :
      addcase 	: adresse du botier mmoire construit par 1 0 1 0 A2 A1 A0 R/W
                remarque (R/W doit tre mis  zro)
      adressmap : adresse  atteindre dans le botier

Sorties : contenu des 32 adresses  partir de adressmap du botier situ en addcase
---------------------------------------------------------------------------------------------------------*/

// --------------------------------------------------------------------------------------------------------
int RegleHTR(unsigned char AddPCF8583, unsigned char HeureOuDate, unsigned char HeureOuJour,
unsigned char MinutesOuMois, unsigned int SecondeOuAnnee);
// --------------------------------------------------------------------------------------------------------
// Etats du graphe des transitions "REGLAGE"
// --------------------------------------------------------------------------------------------------------
#ifndef Regle_Heure_ou_date
#define Regle_Heure_ou_date	    0
#endif
#ifndef Regle_min_mois
#define Regle_min_mois		    1
#endif
#ifndef Regle_seconde_annee
#define Regle_seconde_annee 	2
#endif
#ifndef Mise_a_jour_HTR
#define Mise_a_jour_HTR		    3
#endif
/* --------------------------------------------------------------------------------------------------------
Rle : Rgle la date et l'heure d'une HTR PCF8583 situe  adresse (0 ou 1)

Commentaires :
La fonction rgle l'heure si Heure_ou_Date = 0 ou de la date si Heure_ou_Date = 1.
Les paramtres H_J, mn_mois, sec_annee servent de base aux rglages.
Celui-ci s'effectue avec les BP :
- INC pour augmenter une valeur,
- DEC pour diminuer une valeur,
- OK  pour valider la valeur modifie et passer au rglage suivant
- EChap pour transfrer la valeur rgle et sortir de la fonction

Librairie utilise : PCF8583.h

Entres :
	adresse : adresse du boitier (0 ou 1 selon A0)
	Si Heure_ou_Date = 0 (rglage de l'heure) alors -1 < H_J < 24, -1 < mn_mois < 60
							-1 < sec_annee < 60
						  sinon -1 < H_J < 32, 0 < mn_mois < 13
							1999 < sec_annee < 2050
Sortie : la fonction renvoie 0
---------------------------------------------------------------------------------------------------------*/
// ********************************************************************************************************

// ********************************************************************************************************
// Prototype des fonctions destines aux PPE et aux TP
// ********************************************************************************************************
// ********************************************************************************************************
// PPE Acces lyce: D2000_read, D2000_write
// PPE Pousse seringue: Menu_Select_Seringue, Regdebit
// PPE Doppler: RegVitesse
// ********************************************************************************************************

// ********************************************************************************************************
// Fonctions dveloppes pour le PPE Accs lyce
// --------------------------------------------------------------------------------------------------------
unsigned char D2000_read(unsigned char adreemap);
/* --------------------------------------------------------------------------------------------------------
Rle : Lit un octet dans une carte  puce D2000 (gre par le protocole I2C)

Commentaires : Mmoire eeprom de type PCF8582 (256 octets)
		@botier fig en 0xa0

Librairie utilise : I2C.h

Entres : adressmap = adresse  atteindre dans le botier

Sorties : contenu de l'adresse adressmap du botier situ en 0xa0
---------------------------------------------------------------------------------------------------------*/
// --------------------------------------------------------------------------------------------------------
void D2000_write(unsigned char adressmap, unsigned char data);
/* --------------------------------------------------------------------------------------------------------
Rle : Ecrit un octet dans une carte  puce D2000 (gre par le protocole I2C)

Commentaires : Mmoire eeprom de type PCF8582 (256 octets)
               Adresse du botier fige en 0xa0

Librairie utilise : I2C.h

Entres :
          adressmap = adresse  atteindre dans le botier
          data = caractre  crire

Sorties : aucunes
---------------------------------------------------------------------------------------------------------*/

// ********************************************************************************************************
// Fonctions dveloppes pour le PPE/TP Pousse seringue
//--------------------------------------------------------------------------------------------------------
// 1 int Regdebit(unsigned int *dizaines,unsigned int *unites, unsigned int *diziemes);
// 2 unsigned char Select_Seringue(void);
//
// ********************************************************************************************************
// --------------------------------------------------------------------------------------------------------
unsigned char Regdebit(unsigned int *dizaines,unsigned int *unites, unsigned int *diziemes);
/* --------------------------------------------------------------------------------------------------------
Rle : Renvoie la valeur de la consigne de dbit rgle sous la forme dizaine, unit, dizime

Commentaires : fonction crite pour le pousse seringue

Librairie utilise : lcd.h et stdio.h

Entres / sortie : dizaine de ml/h, unit ml/h, dizime ml/h
---------------------------------------------------------------------------------------------------------*/
// --------------------------------------------------------------------------------------------------------
unsigned char Menu_Select_Seringue(void);
/* --------------------------------------------------------------------------------------------------------
Rle : Renvoie le type de la seringue slectionne
	 0 : TERUMO 50CC	1 : MONOJECT/ BD 50CC	        2 : BD 20CC

Commentaires : fonction crite pour le pousse seringue

Librairie utilise : lcd.h et stdio.h

sortie : seringue slectionne
---------------------------------------------------------------------------------------------------------*/
// ********************************************************************************************************


// ********************************************************************************************************
// Fonctions dveloppes pour les PPE Doppler
//--------------------------------------------------------------------------------------------------------
// 1 int RegVitesse(unsigned int *unites,unsigned int *diziemes, unsigned int *centiemes);
// 2 unsigned char Menu_Select_Sens(void);
// 3 void ActiveTimer(void);
// 4 void DesactiveTimer(void);
// *******************************************************************************************************
// --------------------------------------------------------------------------------------------------------
unsigned int RegVitesse(unsigned int *unites,unsigned int *diziemes, unsigned int *centiemes);
/* --------------------------------------------------------------------------------------------------------
Rle : Renvoie la valeur de la consigne de Vitesse rgle sous la forme unit, dizime, centime
de mm

Commentaires : fonction crite pour le PPE Doppler

Librairie utilise : lcd.h et stdio.h

Entres / sortie : unit mm/s, dizime mm/s, centime de mm/s,
---------------------------------------------------------------------------------------------------------*/
// --------------------------------------------------------------------------------------------------------
unsigned char Menu_Select_Sens(void);
/* --------------------------------------------------------------------------------------------------------
Rle : Renvoie le sens de dplacement choisi
	0: Rentrer	1: Sortir

Commentaires : fonction crite pour le PPE Doppler

Librairie utilise : lcd.h et stdio.h

Entres : rien 		Sortie: sens
---------------------------------------------------------------------------------------------------------*/
// --------------------------------------------------------------------------------------------------------
void ActiveTimer(void);
/* --------------------------------------------------------------------------------------------------------
Rle : Autoriser le fonctionnement du timer1

Commentaires : fonction crite pour le PPE Doppler

Entres / sortie : rien
---------------------------------------------------------------------------------------------------------*/
// --------------------------------------------------------------------------------------------------------
void DesactiveTimer(void);
//--------------------------------------------------------------------------------------------------------
/* --------------------------------------------------------------------------------------------------------
Rle : Inhiber le fonctionnement du timer1

Commentaires : fonction crite pour le PPE Doppler

Entres / sortie : rien
---------------------------------------------------------------------------------------------------------*/

#pragma used-

#pragma library ssi2.lib

#endif    // termine la directive ifndef
